import { NextIntlClientProvider, useMessages } from "next-intl";
import type { Metadata } from "next";
import { Inter } from "next/font/google";
import "../globals.css";
import { IBaseLayoutProps } from "@/lib/types";
import { i18nConfig } from "@/i18n/config";
import { unstable_setRequestLocale } from "next-intl/server";
import Header from "@/components/shared/header";
import { config } from "@fortawesome/fontawesome-svg-core";
import "@fortawesome/fontawesome-svg-core/styles.css";
import "swiper/css";
import "swiper/css/navigation";
import "swiper/css/pagination";
import "swiper/css/autoplay";
import Hero from "@/components/shared/hero";
import Footer from "@/components/shared/footer";
import ActiveSectionProvider from "@/context/active-section";

config.autoAddCss = false;

const inter = Inter({ subsets: ["latin"] });

export function generateStaticParams() {
  return i18nConfig.locales.map((locale) => ({ locale }));
}

export default function RootLayout({
  children,
  params: { locale },
}: IBaseLayoutProps) {
  const messages = useMessages();
  unstable_setRequestLocale(locale);

  return (
    <html
      lang={locale}
      dir={locale === "ar" ? "rtl" : "ltr"}
      className="scroll-smooth"
    >
      <NextIntlClientProvider locale={locale} messages={messages}>
        <ActiveSectionProvider>
          <body className={inter.className}>
            <Header />
            <Hero />
            <div className="mx-auto max-w-supported">{children}</div>
            <Footer />
          </body>
        </ActiveSectionProvider>
      </NextIntlClientProvider>
    </html>
  );
}
