import About from "@/components/home/about";
import DownloadApp from "@/components/home/download-app";
import Reviews from "@/components/home/reviews";
import Services from "@/components/home/services";
import { IBasePageProps } from "@/lib/types";
import { Metadata } from "next";
import { getTranslations, unstable_setRequestLocale } from "next-intl/server";
import path from "path";

export async function generateMetadata({
  params: { locale },
}: IBasePageProps): Promise<Metadata> {
  const t = await getTranslations({ locale, namespace: "meta" });

  return {
    title: t("title"),
    description: t("description"),
    keywords: t("keywords"),
    alternates: {
      canonical: new URL(path.join(process.env.NEXT_PUBLIC_APP_URL!, locale)),
    },
  };
}

export default async function Home({ params: { locale } }: IBasePageProps) {
  unstable_setRequestLocale(locale);

  return (
    <main>
      <About />
      <Services />
      <Reviews />
      <DownloadApp />
    </main>
  );
}
