import { useTranslations } from "next-intl";
import SectionHeader from "../section-header";
import Image from "next/image";
import ActiveSectionListener from "../active-section-listener";
import { fetchApi } from "@/lib/api/server-side";

export default async function About() {
  const t = useTranslations("about");
  const res = await fetchApi("about");
  if (!res.ok) {
    console.error("failed to fetch 'about-us' data because ", res.statusText);
    return <></>;
  }

  const data = (await res.json())?.data as
    | { image: string; about: string }
    | undefined;
  if (!data) {
    console.error("'abous-us' response is not in the expected format");
    return <></>;
  }

  const { image, about } = data;

  return (
    <section
      id="about-us"
      className="relative my-xl-2xl scroll-mt-36"
      dir="ltr"
    >
      <ActiveSectionListener section="about-us" />
      <SectionHeader>{t("about")}</SectionHeader>
      <div className="relative -z-10 aspect-[16/6]">
        <Image
          src={image}
          alt={t("modern-silver-car")}
          fill
          sizes="100vw"
          className="object-cover"
        />
        <div className="absolute inset-0 bg-secondary-1/50 mix-blend-multiply" />
      </div>
      <p className="start-m-l top-1/2 max-w-[36ch] text-center text-xl max-md:mx-auto max-md:p-s-m max-md:text-base md:absolute md:-translate-y-1/2 md:text-gray-50">
        {about}
      </p>
    </section>
  );
}
