import Image from "next/image";
import handHoldingPhone from "../../../../public/assets/images/hand-holding-phone.png";
import appStore from "../../../../public/assets/images/app-store-download.png";
import playStore from "../../../../public/assets/images/play-store-download.png";
import { useTranslations } from "next-intl";
import ActiveSectionListener from "../active-section-listener";
import { fetchApi } from "@/lib/api/server-side";

export default async function DownloadApp() {
  const t = useTranslations("download-app");

  const res = await fetchApi("/app/download");
  const links = (await res.json()) as
    | { android_url?: string; ios_url?: string }
    | undefined;

  if (!links) {
    console.error("'donwload' response is not in the expected format");
    return <></>;
  }

  return (
    <section
      id="mobile-application"
      className="scroll-mt-36k relative mt-2xl-3xl"
    >
      <div className="relative aspect-[3]">
        {/* <Image
          src="https://i.imgur.com/vKD8SC8.png"
          alt={t("modern-car-by-the-sea")}
          fill
          sizes="100vw"
        /> */}
        <div className="absolute inset-0 mix-blend-multiply" />
      </div>

      <Image
        src={handHoldingPhone}
        alt={t("hand-holding-phone")}
        className="absolute -bottom-6 left-0 z-10 w-[45vw] max-w-[800px]"
        sizes="45vw"
      />

      <div className="absolute right-l-xl top-1/2 flex -translate-y-1/2 flex-col items-center gap-xs-s py-m-l max-sm:right-s-m max-sm:gap-3xs-2xs">
        {(links.android_url || links.ios_url) && (
          <h2 className="text-2xl max-sm:text-lg">{t("download-app")}</h2>
        )}

        {links.ios_url && (
          <a
            rel="noreferrer noopener nofollow"
            target="_blank"
            href={links.ios_url}
          >
            <Image
              src={appStore}
              alt={t("app-store-download-button")}
              className="w-[30vw] max-w-[500px] max-sm:w-[25vw]"
              sizes="(min-width: 640px) 30vw, 25vw"
            />
          </a>
        )}

        {links.ios_url && (
          <a
            rel="noreferrer noopener nofollow"
            target="_blank"
            href={links.android_url}
          >
            <Image
              src={playStore}
              alt={t("play-store-download-button")}
              sizes="(min-width: 640px) 30vw, 25vw"
              className="w-[30vw] max-w-[500px] max-sm:w-[25vw]"
            />
          </a>
        )}
      </div>
      <ActiveSectionListener section="mobile-application" />
    </section>
  );
}
