import { cn } from "@/i18n/util/cn";
import { TReview } from "@/lib/types";
import { useTranslations } from "next-intl";
import Image from "next/image";
import { HTMLAttributes } from "react";

export default function ReviewCard({
  className,
  review,
  ...rest
}: { review: TReview } & HTMLAttributes<HTMLElement>) {
  const t = useTranslations("reviews");

  // NOTE: this probably has no effect since this component currently runs on the client side but why not
  const positiveeAdjectives = [
    t("positive-reviews.great"),
    t("positive-reviews.amazing"),
    t("positive-reviews.awesome"),
    t("positive-reviews.happy"),
    t("positive-reviews.satisfied"),
    t("positive-reviews.excellent"),
    t("positive-reviews.fantastic"),
    t("positive-reviews.wonderful"),
    t("positive-reviews.fantabulous"),
    t("positive-reviews.incredible"),
    t("positive-reviews.outstanding"),
  ];

  function getRandomPositiveAdjective() {
    return positiveeAdjectives[
      Math.floor(Math.random() * positiveeAdjectives.length)
    ];
  }

  console.log(getRandomPositiveAdjective());

  return (
    <div
      className={cn(
        "relative mx-xs-s block aspect-[12/16] w-[20rem] overflow-hidden rounded-[38px] border-2 border-accent-1 max-md:w-[16rem]",
        className,
      )}
      {...rest}
    >
      <Image
        src={review.image ?? ""}
        alt={getRandomPositiveAdjective() + " " + t("customer-review")}
        fill
        sizes="20rem"
        className="transition-all duration-700 ease-out hover:scale-105"
      />
    </div>
  );
}
