"use client";

import Marquee from "react-fast-marquee";
import ReviewCard from "../review-card";
import { useCallback, useState } from "react";
import ImageViewer from "react-simple-image-viewer";
import { TReview } from "@/lib/types";

type Props = {
  reviews: TReview[];
};

export default function ReviewsMarquee({ reviews }: Props) {
  const [currentImage, setCurrentImage] = useState(0);
  const [isViewerOpen, setIsViewerOpen] = useState(false);

  const openImageViewer = useCallback((index: number) => {
    setCurrentImage(index);
    setIsViewerOpen(true);
  }, []);

  const closeImageViewer = () => {
    setCurrentImage(0);
    setIsViewerOpen(false);
  };

  const images = reviews
    .flatMap((review) => review.image)
    .filter((v): v is string => Boolean(v));

  return (
    <>
      <div dir="ltr">
        <Marquee autoFill speed={40} className="my-l-xl">
          {reviews.map((review, index) => (
            <ReviewCard
              key={index}
              review={review}
              onClick={() => openImageViewer(index)}
              className="cursor-pointer"
            />
          ))}
        </Marquee>
      </div>

      {isViewerOpen && (
        <ImageViewer
          src={images}
          currentIndex={currentImage}
          disableScroll
          closeOnClickOutside={true}
          onClose={closeImageViewer}
          backgroundStyle={{
            backgroundColor: "rgba(0, 0, 0, 0.7)",
            backdropFilter: "blur(5px)",
            zIndex: 40,
          }}
        />
      )}
    </>
  );
}
