import { useTranslations } from "next-intl";
import SectionHeader from "../section-header";
import dynamic from "next/dynamic";
import ActiveSectionListener from "../active-section-listener";
import { fetchApi } from "@/lib/api/server-side";
import { TReview } from "@/lib/types";

const ReviewsMarquee = dynamic(() => import("./components/reviews-marquee"), {
  ssr: false,
});

export default async function Reviews() {
  const t = useTranslations("reviews");

  const res = await fetchApi("testimonials");
  if (!res.ok) {
    console.error(
      "failed to fetch 'testimonials' data because ",
      res.statusText,
    );
    return <></>;
  }

  const reviews = (await res.json())?.data as TReview[] | undefined;
  if (!reviews?.length) {
    console.error("'testimonials' response is not in the expected format");
    return <></>;
  }

  return (
    <section id="reviews" className="my-xl-2xl scroll-mt-36">
      <SectionHeader short>{t("reviews")}</SectionHeader>
      <ReviewsMarquee reviews={reviews} />
      <ActiveSectionListener section="reviews" />
    </section>
  );
}
