import SectionHeader from "../section-header";
import { TService } from "@/lib/types";
import { useTranslations } from "next-intl";
import ServiceCard from "./components/service-card";
import ActiveSectionListener from "../active-section-listener";
import { fetchApi } from "@/lib/api/server-side";

export default async function Services() {
  const t = useTranslations("services");

  const res = await fetchApi("main-categories");
  if (!res.ok) {
    console.error(
      "failed to fetch 'main-categories' data because ",
      res.statusText,
    );
    return <></>;
  }

  const services = (await res.json())?.data as TService[] | undefined;
  if (!services?.length) {
    console.error("'main-categories' response is not in the expected format");
    return <></>;
  }

  return (
    <section id="services" className="my-xl-2xl scroll-mt-36">
      <SectionHeader short>{t("services")}</SectionHeader>
      <ul className="mt-l-xl grid grid-cols-[repeat(auto-fit,_minmax(11rem,_1fr))] gap-s-m px-page max-md:grid-cols-2">
        {services.map((service, index) => (
          <li key={index}>
            <ServiceCard service={service} />
          </li>
        ))}
      </ul>
      <ActiveSectionListener section="services" />
    </section>
  );
}
