"use client";

import { faAlignLeft, faBars } from "@fortawesome/free-solid-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { useState } from "react";
import NavigationItem, { TNavigationItem } from "../navigation-item";
import { cn } from "@/i18n/util/cn";
import LanguageSwitcher from "../language-switcher";

type Props = {
  items: TNavigationItem[];
};

export default function MobileMenu({ items }: Props) {
  const [isOpen, setIsOpen] = useState(false);

  function toggle() {
    setIsOpen((prev) => !prev);
  }

  return (
    <>
      <button onClick={toggle} className="outline-none md:hidden">
        <FontAwesomeIcon icon={faBars} className="text-white" size="xl" />
      </button>

      <nav
        className={cn(
          "absolute inset-x-0 top-[66px] rounded-b-2xl bg-secondary-1 py-m-l transition-all",
          {
            "pointer-events-none opacity-0 duration-150": !isOpen,
            "opacity-100 duration-75": isOpen,
          },
        )}
      >
        <ul className="flex flex-col items-center gap-s-m">
          {items.map((item, index) => (
            <li key={index}>
              <NavigationItem item={item} onClick={toggle} />
            </li>
          ))}

          <li>
            <LanguageSwitcher className="max-md:bg-accent-1" />
          </li>
        </ul>
      </nav>
    </>
  );
}
