"use client";

import { useActiveSection } from "@/context/active-section";
import { Link, usePathname } from "@/i18n/navigation";
import { cn } from "@/i18n/util/cn";
import { TSectionName } from "@/lib/types";
import { useParams } from "next/navigation";
import { useEffect, useState } from "react";

export type TNavigationItem = {
  section: TSectionName;
  title: string;
  href: string;
};

type Props = {
  item: TNavigationItem;
  onClick?: () => void;
};

export default function NavigationItem({
  item: { title, href, section },
  onClick,
}: Props) {
  const params = useParams();
  // const [hashTag, setHashTag] = useState("");
  const { activeSection, setActiveSection, setTimeOfLastClick } =
    useActiveSection();

  // useEffect(() => {
  //   setHashTag(window.location.hash);
  // }, [params]);

  function handleClick() {
    setActiveSection(section);
    setTimeOfLastClick(Date.now());

    if (onClick) {
      onClick();
    }
  }

  return (
    <Link
      href={href}
      className={cn(
        "text-base font-extralight text-gray-50 transition-all hover:text-accent-1",
        { "font-medium text-accent-1": activeSection === section },
      )}
      onClick={handleClick}
    >
      {title}
    </Link>
  );
}
