import { HTMLAttributes } from "react";
import Logo from "../logo";
import { useTranslations } from "next-intl";
import LanguageSwitcher from "./components/language-switcher";
import Slogan from "../slogan";
import NavigationItem, { TNavigationItem } from "./components/navigation-item";
import MobileMenu from "./components/mobile-menu";

export default function Header({}: HTMLAttributes<HTMLElement>) {
  const t = useTranslations("header");
  const links: TNavigationItem[] = [
    {
      section: "about-us",
      title: t("about-us"),
      href: "#about-us",
    },
    {
      section: "services",
      title: t("services"),
      href: "#services",
    },
    {
      section: "reviews",
      title: t("reviews"),
      href: "#reviews",
    },
    {
      section: "mobile-application",
      title: t("download-app"),
      href: "#mobile-application",
    },
  ] as const;

  return (
    <div className="sticky top-0 z-50 border-b-8 border-accent-1 bg-secondary-1 px-m-l py-3xs-2xs">
      <header className="mx-auto flex max-w-supported items-center justify-between">
        <Slogan className="max-md:hidden" />
        <MobileMenu items={links} />

        <nav className="flex items-center justify-between gap-s-m max-md:hidden">
          <ul className="flex items-center justify-between gap-s-m">
            {links.map((item, index) => (
              <li key={index}>
                <NavigationItem item={item} />
              </li>
            ))}
          </ul>

          <LanguageSwitcher />
        </nav>

        <Logo />
      </header>
    </div>
  );
}
