import type { Config } from 'tailwindcss';

const config: Config = {
  content: [
    './src/pages/**/*.{js,ts,jsx,tsx,mdx}',
    './src/components/**/*.{js,ts,jsx,tsx,mdx}',
    './src/app/**/*.{js,ts,jsx,tsx,mdx}',
  ],
  theme: {
    extend: {
      width: {
        readable: '70ch',
      },
      maxWidth: {
        supported: '1920px',
      },
      minWidth: {
        supported: '350px',
      },
      colors: {
        primary: {
          1: 'rgb(var(--primary-bg-color-1) / <alpha-value>)',
        },
        'primary-fg': {
          1: 'rgb(var(--primary-fg-color-1) / <alpha-value>)',
        },
        secondary: {
          1: 'rgb(var(--secondary-color-1) / <alpha-value>)',
        },
        accent: {
          1: 'rgb(var(--accent-color-1) / <alpha-value>)',
        },
      },
      screens: {
        "2xs": "380px",
      },
      spacing: {
        /* Space 3xs-2xs: 4px → 10px */
        '3xs-2xs': 'var(--space-3xs-2xs)',
        /* Space 2xs-xs: 8px → 15px */
        '2xs-xs': 'var(--space-2xs-xs)',
        /* Space xs-s: 12px → 20px */
        'xs-s': 'var(--space-xs-s)',
        /* Space s-m: 16px → 30px */
        's-m': 'var(--space-s-m)',
        /* Space m-l: 24px → 40px */
        'm-l': 'var(--space-m-l)',
        /* Space l-xl: 32px → 60px */
        'l-xl': 'var(--space-l-xl)',
        /* Space xl-2xl: 48px → 80px */
        'xl-2xl': 'var(--space-xl-2xl)',
        /* Space 2xl-3xl: 64px → 120px */
        '2xl-3xl': 'var(--space-2xl-3xl)',
        page: 'var(--space-page)',
      },
      fontSize: {
        /* Step -2: 11.1111px → 12.8px */
        xs: 'var(--text-xs)',
        /* Step -1: 13.3333px → 16px */
        sm: 'var(--text-sm)',
        /* Step 0: 16px → 20px */
        base: 'var(--text-base)',
        /* Step 5: 39.8131px → 61.0352px */
        lg: 'var(--text-lg)',
        /* Step 2: 23.04px → 31.25px */
        xl: 'var(--text-xl)',
        /* Step 3: 27.648px → 39.0625px */
        '2xl': 'var(--text-2xl)',
        /* Step 4: 33.1776px → 48.8281px */
        '3xl': 'var(--text-3xl)',
        /* Step 5: 39.8131px → 61.0352px */
        '4xl': 'var(--text-4xl)',
      },
    },
  },
  plugins: [require('tailwind-scrollbar-hide'), require('tailwindcss-dir')()],
};
export default config;
